@@ -41,6 +41,7 @@ define("ks3_connect_config", default={}, type=dict, help="金山对象存储连
 define("scheduler", default=None, type=TornadoScheduler, help="Tornado任务调度")
 define("scheduler_config", default={}, type=dict, help="Tornado任务调度配置")
 define("nacos_config", default={}, type=dict, help="nacos配置")
+define("restful_handler", default=[], type=list, help="restful handler")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -117,8 +118,9 @@ class WebServer:
         self.autoRegisterExtendHandler()
         if options.scheduler_config.get("enable", False):
             self.init_scheduler()
+        handlers = options.restful_handler+RouterMapping.instance()
         self.app = tornado.web.Application(
-            RouterMapping.instance(),
+            handlers,
             cookie_secret=options.cookie_secret,
             static_path=options.static_path,
             db=options.db,
